% IMP_CABA : modified version of impresp.m 
% USED TO PLOT IMPULSE RESPONSES TO SHOCKS IN THE PAPER
% DOMESTIC AND INTERNATIONAL COLLATERAL AND IBC


% VERSION 2.0, MARCH 1997, COPYRIGHT H. UHLIG.
% IMPRESP.M calculates and plots impulse responses to shocks one percent
% in size to each one of the exogenous variables z(t), keeping all
% others at zero in the first period.  It is assumed,
% that SOLVE.M has been executed before, so that the matrices
% NN, PP, QQ, RR and SS are available, describing the law of motion
%   x(t) = PP x(t-1) + QQ z(t)
%   y(t) = RR x(t-1) + SS z(t)
%   z(t) = NN z(t-1) + epsilon(t)
% The following options should have been chosen beforehand (see also file OPTIONS.M)
%   HORIZON    : how far out should the impulse responses be calculated
%   PERIOD     : number of periods per year, i.e. 12 for monthly, 4 for quarterly
%   DO_PLOTS   : = 1, if plots should be made, = 0, if not.
%   IMP_SELECT : a vector containing the indices of the variables to be
%             plotted.  To plot all variables, set IMP_SELECT = 1 : (m+n+k),
%             where m=dim(x), n=dim(y) and k=dim(z);
%   VARNAMES   : an array with (m+n+k) rows, containing the variable names.
%   The following options are set in OPTIONS.M:
%   TXT_MARKER : a number indicating where the label for the responses should be written.
%   DO_ENLARGE : = 1, if you want large font sizes for the text on your plots.  Good for slides.
%   PRINT_FIG  : = 1, if you want plots to be printed on your printer
%   SAVE_FIG   : = 1, if you want plots to be saved as encaps. postscript.  Set PRINT_FIG = 0 also.
% The program calculates:
% Response: the response of all variables x(t), y(t), z(t) to each shock.
%   Response is of size (m_states+n_endog+k_exog)*HORIZON.
%   Since Response is overwritten, each time a new shock is analyzed, 
%   the results are collected in 
% Resp_mat = [ Response to first shock
%              Response to second shock
%              ...                     ]
%
% The program also defines 
% Time_axis,m_states,n_endog,k_exog,II_contemp,II_lag,hndl,
% thus overwriting variables with these names that might have been used before.


% Copyright: H. Uhlig.  Feel free to copy, modify and use at your own risk.
% However, you are not allowed to sell this software or otherwise impinge
% on its free distribution.

% Most options are now set in OPTIONS.M

% Calculations
[m_states,k_exog] = size(QQ);
[n_endog,k_exog]  = size(SS);
Time_axis = (0 : (HORIZON-1))/PERIOD;
Resp_mat = [];
for shock_counter = 1 : k_exog,
   Response = zeros(m_states+n_endog+k_exog,HORIZON);
   Response(m_states+n_endog+shock_counter,1) = 1;
   II_lag = [ PP, zeros(m_states,n_endog),zeros(m_states,k_exog)
              RR, zeros(n_endog, n_endog),zeros(n_endog, k_exog)
              zeros(k_exog,(m_states+n_endog)), NN                ];
   II_contemp = eye(m_states+n_endog+k_exog) + ...
        [ zeros(m_states,(m_states+n_endog)), QQ
          zeros(n_endog, (m_states+n_endog)), SS
          zeros(k_exog,  (m_states+n_endog)), zeros(k_exog,k_exog) ];
   % describing [x(t)',y(t)',z(t)']'= II_contemp*II_lag*[x(t-1)',y(t-1)',z(t-1)']';
   Response(:,1) = II_contemp*Response(:,1);
   for time_counter = 2 : HORIZON,
      Response(:,time_counter) = II_contemp*II_lag*Response(:,time_counter-1);
   end;
   Resp_mat = [ Resp_mat 
                Response ];
                
%                 Resp_mat = round(1000000*Resp_mat)/1000000;
%                 Response = round(1000000*Response)/1000000;

                if DO_PLOTS,

                  
if cha==0;   symbol1='-k';   symbol2='o--r'; end
if cha==1;   symbol1='--k';   symbol2='^:b'; end
if cha==2;   symbol1=':b';   symbol2='s:b'; end
if cha==3;   symbol1='*-g';   symbol2='*:g'; end
if cha==4;   symbol1='d-m';   symbol2='d:m'; end

if cha==1 | cha==2 | cha==3 | cha==4 ; hold on; end



% hndl = plot(Time_axis,0*Time_axis, Time_axis,Response(IMP_SELECT,:),symbol1); 
  hndl = plot(Time_axis,Response(IMP_SELECT,:),symbol1); 
          
          
                            end
                           
     
                            
% set(hndl(2:max(size(hndl))),'LineWidth',2,'markersize',5-cha); 
  set(hndl(1:max(size(hndl))),'LineWidth',1,'markersize',4); 
                           
                           

      xlabel(VARNAMES(IMP_SELECT,:));
%       ylabel('%');

      

end